suppy.perturbations
===========================

Module contents
---------------

.. autoclass:: suppy.perturbations._base.Perturbation
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: suppy.perturbations._base.ObjectivePerturbation
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: suppy.perturbations._base.GradientPerturbation
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: suppy.perturbations.PowerSeriesGradientPerturbation
    :members:
    :undoc-members:
    :show-inheritance:
